@@ -2,7 +2,7 @@ package Perinci::Sub::ValidateArgs;
 
 # NOIFBUILT
 our $DATE = '2016-05-23'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict 'subs', 'vars';
 use warnings;
@@ -50,10 +50,10 @@ sub validate_args {
         my $validator = $validator_cache{$cache_key};
         if (!$validator) {
             $validator = Data::Sah::gen_validator(
-                $schema, {return_type=>'str+val'});
+                $schema, {return_type=>'str'});
             $validator_cache{$cache_key} = $validator;
         }
-        ($err, $args->{$arg_name}) = @{ $validator->($args->{$arg_name}) };
+        $err = $validator->($args->{$arg_name});
         if ($err) {
             $err = "Validation failed for argument '$arg_name': $err";
             if ($result_naked) { die $err } else { return [400, $err] }
@@ -78,7 +78,7 @@ Perinci::Sub::ValidateArgs - Validate function arguments
 
 =head1 VERSION
 
-This document describes version 0.002 of Perinci::Sub::ValidateArgs (from Perl distribution Perinci-Sub-ValidateArgs), released on 2016-05-23.
+This document describes version 0.003 of Perinci::Sub::ValidateArgs (from Perl distribution Perinci-Sub-ValidateArgs), released on 2016-05-23.
 
 =head1 SYNOPSIS
 
